Grayscale
=========

Usage: grayscale()

Description
-----------

This filter changes the image to grayscale.

Arguments
---------

No arguments.

Example
-------

.. image:: images/tom_before_brightness.jpg
    :alt: Picture before the grayscale filter

`<http://thumbor-server/filters:grayscale()/some/image.jpg>`_

.. image:: images/tom_after_grayscale.jpg
    :alt: Picture after the grayscale filter
